package com.boyue.hasfj.service;

import java.util.List;
import com.boyue.hasfj.domain.UserFeedback;

/**
 * 用户留言Service接口
 * 
 * @author boyue
 * @date 2025-07-04
 */
public interface IUserFeedbackService 
{
    /**
     * 查询用户留言
     * 
     * @param id 用户留言主键
     * @return 用户留言
     */
    public UserFeedback selectUserFeedbackById(Long id);

    /**
     * 查询用户留言列表
     * 
     * @param userFeedback 用户留言
     * @return 用户留言集合
     */
    public List<UserFeedback> selectUserFeedbackList(UserFeedback userFeedback);

    /**
     * 新增用户留言
     * 
     * @param userFeedback 用户留言
     * @return 结果
     */
    public int insertUserFeedback(UserFeedback userFeedback);

    /**
     * 修改用户留言
     * 
     * @param userFeedback 用户留言
     * @return 结果
     */
    public int updateUserFeedback(UserFeedback userFeedback);

    /**
     * 批量删除用户留言
     * 
     * @param ids 需要删除的用户留言主键集合
     * @return 结果
     */
    public int deleteUserFeedbackByIds(Long[] ids);

    /**
     * 删除用户留言信息
     * 
     * @param id 用户留言主键
     * @return 结果
     */
    public int deleteUserFeedbackById(Long id);

    /**
     * 查询用户留言
     *
     * @param feedbackNo 留言查询编号
     * @return 用户留言
     */
    public UserFeedback selectUserFeedbackByFeedbackNo(String feedbackNo);
}
